@@ -3,7 +3,7 @@
  * Copyright 1994-1999 Patrick Powell, San Diego, CA <papowell@astart.com>
  **************************************************************************/
 /**** HEADER *****
-$Id: ifhp.h,v 1.36 2002/03/06 04:43:34 papowell Exp papowell $
+$Id: ifhp.h,v 1.40 2002/07/12 23:22:55 papowell Exp papowell $
  **** ENDHEADER ****/
 
 #ifndef _IFHP_H_
@@ -83,6 +83,8 @@ typedef	int (*Builtin_func)(char *, char*, char *, Wr_out);
 #endif
 #define OUTBUFFER (1024*10)
 
+int Peek_char DEFINE( = -1);
+
 /* get the character value at a char * location */
 
 /* EXIT CODES */
@@ -130,6 +132,9 @@ EXTERN char *MSG DEFINE( = "MSG");
     struct glyph *glyph;    /* glyphs */
 };
 
+EXTERN char *Devfd0  DEFINE( = DEVFD0 );
+EXTERN char *InputFile;
+
 /*
  * setup values
  */
@@ -196,7 +201,9 @@ EXTERN int
 	No_udp_monitor,		/* do not use udp monitor */
 	OF_Mode,			/* running in OF mode */
 	Pagecount_interval,	/* pagecount polling interval */
-	Pagecount_poll,	/* pagecount polling interval */
+	Pagecount_poll,	/* pagecount times to poll (default is 1) */
+	Pagecount_poll_start,	/* pagecount times to poll */
+	Pagecount_poll_end,		/* pagecount times to poll */
 	Pagecount_timeout,	/* pagecount */
 	Pagecount_start DEFINE(=1),	/* pagecount at start */
 	Pagecount_end DEFINE(=1),	/* pagecount at end */
@@ -272,6 +279,7 @@ EXTERN jmp_buf Timeout_env;
 
 /* PROTOTYPES */
 void cleanup(int sig);
+void usage();
 void getargs( int argc, char **argv );
 void Fix_special_user_opts( char *name, OBJ *opts, OBJ *unsorted_opts,
 	 char *line );
@@ -281,15 +289,16 @@ void Put_outbuf_len( char *s, int len );
 void Init_inbuf();
 void Put_inbuf_len( char *str, int len );
 void Get_inbuf_str(void);
-void Pr_status( char *str, int monitor_status );
-void Check_device_status( char *line );
+void Pr_status( char *str );
+void Check_device_status( char *line, int infovar );
 void Initialize_parms( OBJ *list, struct keyvalue *valuelist );
 void Dump_parms( char *title, struct keyvalue *v );
-void Process_job( int do_pagecount, int pagecount_ps, int pagecount_pjl );
+void Process_job( int do_pagecount, int pagecount_ps, int pagecount_pjl, char *pagecount_prog );
 void Start_of_job( int *startpagecounter, int do_pagecount, int pagecount_ps,
-	int pagecount_pjl, int nested_job );
+	int pagecount_pjl, int nested_job, char *pagecount_prog );
 void End_of_job( int *startpagecounter, int do_pagecount, int pagecount_ps,
-	int pagecount_pjl, int wait_for_end, int nested_job, int banner_page );
+	int pagecount_pjl, int wait_for_end, int nested_job, int banner_page,
+	char *pagecount_prog );
 int Find_in_list( OBJ *list, const char *str );
 void Put_pjl( char *s );
 void Put_pcl( char *s );
@@ -320,7 +329,7 @@ void Resolve_list( char *prefix, OBJ *list, OBJ *values, Wr_out routine, int dep
 void Resolve_user_opts( char *prefix, OBJ *only,
 	OBJ *list, OBJ *values, Wr_out routine );
 char *Fix_option_str( char *str, int remove_ws, int trim, int one_line );
-char *Find_sub_value( int c, char *id, int strval );
+char *Find_sub_value( int c, char *id, int strval);
 int Builtin( char* prefix, char *id, char *value, Wr_out routine);
 const char *Decode_status (plp_status_t *status);
 int plp_usleep( int i );
@@ -334,18 +343,17 @@ int Pcl_setvar(char *prefix, char*id, char *value, Wr_out routine );
 void Do_sync( int sync_timeout, int sync_interval, int pagecount_pjl );
 void Do_waitend( int waitend_timeout, int waitend_interval,
 	int waitend_ctrl_t_interval, int banner );
-int Check_pagecount( int *use_ps_v, int *use_pjl_v );
+int Check_pagecount( int *use_ps_v, int *use_pjl_v, char **use_prog_v );
 int Do_pagecount( int pagecount_timeout, int pagecount_interval, int pagecount_poll,
-	 int use_ps, int use_pjl );
-int Current_pagecounter( int pagecount_timeout, int pagecount_interval,
-	int use_pjl, int use_ps );
+	 int use_ps, int use_pjl, char *use_prog );
+int Current_pagecounter( int pagecount_timeout, int use_pjl, int use_ps );
 void Send_job();
 void URL_decode( char *s );
 int Process_OF_mode(void);
 void close_on_exec( int n );
 void Set_max_fd( int n );
 void Use_file_util(char *pgm, char *value, int value_len );
-int Make_tempfile( void );
+int Make_tempfile( char **filename );
 void Make_stdin_file();
 char * Set_mode_lang( char *s );
 int Fd_readable( int fd, int *poll_for_status );
@@ -359,5 +367,6 @@ void Make_model_index( OBJ *input, OBJ *index, OBJ *entries );
 OBJ *Make_new_model_entry( char *key, OBJ *index, OBJ *entries,
 	OBJ *items, OBJ *strval );
 void Select_model_info( OBJ *model, OBJ *index, OBJ *entries, char *id, int level, int maxlevel );
+int Get_prog_status( OBJ *devstatus, char *pgm, int timeout );
 
 #endif
