@@ -1695,7 +1695,7 @@ void SHORT_DUMP_OBJ( const char *header, OBJ *p)
 
 void REAL_DUMP_OBJ( int verbose, const char *indent, const char *header, OBJ *p)
 {
-	char buffer[SMALLBUFFER], *s;
+	char buffer[LARGEBUFFER], *s;
 	char newindent[SMALLBUFFER];
 	HASH_ELEMENT *element;
 	int len, i, n, extra;
